"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = usePrism;

var _react = _interopRequireDefault(require("react"));

var _loadModule = _interopRequireDefault(require("../utils/loadModule"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * A React effect hook that highlights code in a given element.

 * - Specify `{isContainer: true}` if your element is not the target, but instead contains target elements. (Uses `Prism.highlightAllUnder` instead of `Prism.highlightElement`)
 * - Specify `{useWorker: true}` to set the `async` flag in the prism highlighter. Only useful for large blocks of code.
 * - Check out the [prism documentation](https://prismjs.com/extending.html#api) for more details
 *
 * @param {Object} ref a React ref to the target element
 * @param {Object} options the options object
 * @param {String} [options.language = 'javascript'] name of the prism language to load
 * @param {String} [options.theme = 'okaidia'] name of the prism theme to load
 * @param {Boolean} [options.isContainer] whether the given element ref is a container
 * @param {Boolean} [options.useWorker] whether to use a web worker for highlighting
 * @param {Function} [options.callback] invoked when prism is done highlighting
 *
 */
function usePrism(ref, options) {
  _react.default.useEffect(function () {
    try {
      applyPrism(ref, options);
    } catch (error) {
      console.warn('[usePrism] failed', {
        error: error
      });
    }
  }, [ref.current || ref, options.language, options.theme, options.isContainer, options.useWorker, options.callback]);
}

function applyPrism(_x) {
  return _applyPrism.apply(this, arguments);
}

function _applyPrism() {
  _applyPrism = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(ref) {
    var _ref,
        _ref$language,
        language,
        _ref$theme,
        theme,
        _ref$isContainer,
        isContainer,
        _ref$useWorker,
        useWorker,
        _ref$callback,
        callback,
        Prism,
        highlight,
        _args = arguments;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref = _args.length > 1 && _args[1] !== undefined ? _args[1] : {}, _ref$language = _ref.language, language = _ref$language === void 0 ? 'javascript' : _ref$language, _ref$theme = _ref.theme, theme = _ref$theme === void 0 ? 'okaidia' : _ref$theme, _ref$isContainer = _ref.isContainer, isContainer = _ref$isContainer === void 0 ? false : _ref$isContainer, _ref$useWorker = _ref.useWorker, useWorker = _ref$useWorker === void 0 ? false : _ref$useWorker, _ref$callback = _ref.callback, callback = _ref$callback === void 0 ? undefined : _ref$callback;
            _context.next = 3;
            return import(
            /* webpackChunkName: 'codeblock/prismjs' */
            'prismjs');

          case 3:
            Prism = _context.sent;
            _context.next = 6;
            return (0, _loadModule.default)('theme', theme);

          case 6:
            _context.next = 8;
            return (0, _loadModule.default)('language', language);

          case 8:
            if (ref && ref.current) {
              highlight = isContainer ? Prism.highlightAllUnder : Prism.highlightElement;
              highlight(ref.current, useWorker, callback);
            }

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _applyPrism.apply(this, arguments);
}